@@ -33,7 +33,7 @@ import org.apache.commons.io.testtools.FileBasedTestCase;
 /**
  * This is used to test FileSystemUtils.
  *
- * @version $Id: FileSystemUtilsTestCase.java 453889 2006-10-07 11:56:25Z scolebourne $
+ * @version $Id: FileSystemUtilsTestCase.java 606380 2007-12-22 01:58:46Z ggregory $
  */
 public class FileSystemUtilsTestCase extends FileBasedTestCase {
 
@@ -90,14 +90,14 @@ public class FileSystemUtilsTestCase extends FileBasedTestCase {
             long free = FileSystemUtils.freeSpace("/");
             long kb = FileSystemUtils.freeSpaceKb("/");
             if (kilobyteBlock) {
-                assertEquals((double) free, (double) kb, 256d);
+                assertEquals(free, kb, 256d);
             } else {
-                assertEquals((double) free / 2d, (double) kb, 256d);
+                assertEquals(free / 2d, kb, 256d);
             }
         } else {
             long bytes = FileSystemUtils.freeSpace("");
             long kb = FileSystemUtils.freeSpaceKb("");
-            assertEquals((double) bytes / 1024, (double) kb, 256d);
+            assertEquals((double) bytes / 1024, kb, 256d);
         }
     }
 
