@@ -16,15 +16,8 @@
  */
 package org.apache.commons.io;
 
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
-import java.io.InputStream;
-import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.io.OutputStreamWriter;
-import java.io.Reader;
-import java.io.StringWriter;
 import java.io.Writer;
 import java.util.Arrays;
 import java.util.List;
@@ -44,7 +37,7 @@ import org.apache.commons.io.testtools.YellOnFlushAndCloseOutputStream;
  * @author Matthew Hawthorne
  * @author Jeremias Maerki
  * @author Stephen Colebourne
- * @version $Id: IOUtilsWriteTestCase.java 437567 2006-08-28 06:39:07Z bayard $
+ * @version $Id: IOUtilsWriteTestCase.java 606381 2007-12-22 02:03:16Z ggregory $
  * @see IOUtils
  */
 public class IOUtilsWriteTestCase extends FileBasedTestCase {
